@@ -8,4 +8,4 @@ from thriftpyi.entities import Content
 
 def render(content: Content) -> str:
     template = Template(resources.read_text("thriftpyi.templates", "stub.html"))
-    return template.render(**asdict(content))
+    return template.render(**asdict(content))  # type: ignore
